@@ -4,32 +4,30 @@ data_location = os.path.join(__dir__, "verilog")
 src = "https://github.com/olofk/serv"
 
 # Module version
-version_str = "1.1.0.post177"
-version_tuple = (1, 1, 0, 177)
+version_str = "1.2.0.post145"
+version_tuple = (1, 2, 0, 145)
 try:
     from packaging.version import Version as V
-    pversion = V("1.1.0.post177")
+    pversion = V("1.2.0.post145")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "1.1.0.post35"
-data_version_tuple = (1, 1, 0, 35)
+data_version_str = "1.2.0.post3"
+data_version_tuple = (1, 2, 0, 3)
 try:
     from packaging.version import Version as V
-    pdata_version = V("1.1.0.post35")
+    pdata_version = V("1.2.0.post3")
 except ImportError:
     pass
-data_git_hash = "4ddd154b249f46522f164aa9a49cce3edfafe03c"
-data_git_describe = "1.1.0-35-g4ddd154"
+data_git_hash = "6ad60f69a20c969ce46a605af9661b224d7e765d"
+data_git_describe = "1.2.0-3-g6ad60f6"
 data_git_msg = """\
-commit 4ddd154b249f46522f164aa9a49cce3edfafe03c
-Author: Wadood <82087831+Abdulwadoodd@users.noreply.github.com>
-Date:   Tue May 17 12:11:56 2022 +0500
+commit 6ad60f69a20c969ce46a605af9661b224d7e765d
+Author: gojimmypi <13059545+gojimmypi@users.noreply.github.com>
+Date:   Thu Dec 23 12:10:43 2021 -0800
 
-    Nexys 2 Board support
-    
-    Added nexys 2 target support for servant
+    Add ICE-V Wireless support
 
 """
 
